summaryrefslogtreecommitdiff
path: root/gr-fcd/python/__init__.py
diff options
context:
space:
mode:
Diffstat (limited to 'gr-fcd/python/__init__.py')
-rw-r--r--gr-fcd/python/__init__.py47
1 files changed, 13 insertions, 34 deletions
diff --git a/gr-fcd/python/__init__.py b/gr-fcd/python/__init__.py
index 76c05ebb3e..9e573450f6 100644
--- a/gr-fcd/python/__init__.py
+++ b/gr-fcd/python/__init__.py
@@ -1,49 +1,28 @@
#
# Copyright 2011 Free Software Foundation, Inc.
#
# This application is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# This application is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
-
-# The presence of this file turns this directory into a Python package
-
-# ----------------------------------------------------------------
-# Temporary workaround for ticket:181 (swig+python problem)
-import sys
-_RTLD_GLOBAL = 0
-try:
- from dl import RTLD_GLOBAL as _RTLD_GLOBAL
-except ImportError:
- try:
- from DLFCN import RTLD_GLOBAL as _RTLD_GLOBAL
- except ImportError:
- pass
-
-if _RTLD_GLOBAL != 0:
- _dlopenflags = sys.getdlopenflags()
- sys.setdlopenflags(_dlopenflags|_RTLD_GLOBAL)
-# ----------------------------------------------------------------
+# You should have received a copy of the GNU General Public License
+# along with GNU Radio; see the file COPYING. If not, write to
+# the Free Software Foundation, Inc., 51 Franklin Street,
+# Boston, MA 02110-1301, USA.
+#
+'''
+This is the gr-fcd package. This package provides a GNU Radio
+source block for the FunCube Dongle hardware.
+'''
-# import swig generated symbols into the fcd namespace
from fcd_swig import *
-# import any pure python here
-#
-
-# ----------------------------------------------------------------
-# Tail of workaround
-if _RTLD_GLOBAL != 0:
- sys.setdlopenflags(_dlopenflags) # Restore original flags
-# ----------------------------------------------------------------
@@ -1,49 +1,28 @@
# Copyright 2011 Free Software Foundation, Inc.
#
-# This application is free software; you can redistribute it and/or modify
+# This file is part of GNU Radio
+#
+# GNU Radio is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
@@ -1,49 +1,28 @@
# any later version.
#
-# This application is distributed in the hope that it will be useful,
+# GNU Radio is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the